@@ -20,7 +20,7 @@ struct SensorEvent {
 
 fn main() -> Result<(), Box<dyn ErrorTrait>> {
     env_logger::init();
-    let mut ditto = Ditto::builder()
+    let ditto = Ditto::builder()
         .with_temp_dir() // no need to store data locally
         .with_minimum_log_level(CLogLevel::Debug)
         .with_identity(|ditto_root| {
