@@ -13,7 +13,7 @@ use_prelude!();
 
 // Identity is pub because it is part of the Builder's public interface
 // It is therefore Sealed to prevent downstream implementations
-pub trait Identity: private::Sealed {
+pub trait Identity: private::Sealed + Send + Sync {
     /// Returns the current SiteId identifying the Ditto peer
     fn site_id(&self) -> SiteId;
 
@@ -47,6 +47,9 @@ pub trait Identity: private::Sealed {
 
     /// Returns the configured URL for websocket sync
     fn sync_url(&self) -> Result<String, DittoError>;
+
+    /// Indicates whether the specific Identity type requires an offline only license token to be set.
+    fn requires_offline_only_license_token(&self) -> bool;
 }
 
 /// Run Ditto in secure production mode, logging on to Ditto Cloud or an
@@ -254,6 +257,10 @@ impl Identity for Online {
     fn make_listener(&self, transports: Arc<RwLock<Transports>>) -> Option<Arc<ValidityListener>> {
         Some(ValidityListener::new(transports, self.auth.auth_client()))
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        false
+    }
 }
 
 impl OnlineWithAuthentication {
@@ -357,6 +364,10 @@ impl Identity for OnlineWithAuthentication {
     fn make_listener(&self, transports: Arc<RwLock<Transports>>) -> Option<Arc<ValidityListener>> {
         Some(ValidityListener::new(transports, self.auth.auth_client()))
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        false
+    }
 }
 
 impl Development {
@@ -439,6 +450,10 @@ impl Identity for Development {
     fn make_listener(&self, transports: Arc<RwLock<Transports>>) -> Option<Arc<ValidityListener>> {
         Some(ValidityListener::new(transports, self.auth.auth_client()))
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        true
+    }
 }
 
 impl OfflinePlayground {
@@ -521,6 +536,10 @@ impl Identity for OfflinePlayground {
     fn make_listener(&self, transports: Arc<RwLock<Transports>>) -> Option<Arc<ValidityListener>> {
         Some(ValidityListener::new(transports, self.auth.auth_client()))
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        true
+    }
 }
 
 impl SharedKey {
@@ -602,6 +621,10 @@ impl Identity for SharedKey {
     fn is_cloud_sync_enabled(&self) -> bool {
         false
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        true
+    }
 }
 
 impl Manual {
@@ -675,6 +698,10 @@ impl Identity for Manual {
     fn is_cloud_sync_enabled(&self) -> bool {
         false
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        true
+    }
 }
 
 impl OnlinePlayground {
@@ -767,6 +794,10 @@ impl Identity for OnlinePlayground {
     fn is_cloud_sync_enabled(&self) -> bool {
         self.enable_cloud_sync
     }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        false
+    }
 }
 
 mod private {
