@@ -42,6 +42,18 @@ pub fn get_inactive_ditto() -> Result<Ditto, DittoError> {
     Ok(ditto)
 }
 
+#[allow(dead_code)]
+pub fn get_online_ditto() -> Result<Ditto, DittoError> {
+    let ditto = Ditto::builder()
+        .with_temp_dir()
+        .with_identity(|ditto_root| {
+            identity::OnlinePlayground::new(ditto_root, AppId::generate(), false, None)
+        })?
+        .with_minimum_log_level(CLogLevel::Info)
+        .build()?;
+    Ok(ditto)
+}
+
 // A Re-usable test document type
 #[derive(Serialize, Deserialize, Debug, PartialEq, Eq, Clone)]
 pub enum TestColor {
